declare
  attestation_id      numeric(16);
  view_conf_name      varchar(128);
  view_conf_position  numeric(16);
  view_conf_id        numeric(16);
  view_conf_visible   numeric(16);
  v_name              varchar(128);

  counter             numeric(16);
  cur_attest          sys_refcursor;

begin
------ENTITLEMENT_VIEW SECTION
  v_name := 'Entitlement_View';

  open cur_attest for
  select att.id from attestation att where type=1 and state not in (5, 10); 
    loop
    fetch cur_attest into attestation_id;
    exit when cur_attest%NOTFOUND;
    
    view_conf_name := 'UE_TABULAR_REVIEW_PROCESS';
    view_conf_visible := 0;
    select count(1) into counter from attestation_view attview where attview.field = view_conf_name and attview.attestation = attestation_id;
    if ( counter = 0 or counter > 1) then
    	delete from attestation_view attview where attview.field = view_conf_name and attview.attestation = attestation_id;
    	select attestation_view_seq.nextval into view_conf_id from dual;
    	select ( max(t.position) + 1 ) into view_conf_position from attestation_view t where t.attestation = attestation_id and ( view_name is null or view_name <> 'User_View' );
    	if( view_conf_position is null ) then
    		view_conf_position := 1;
    	end if;
        insert into attestation_view (id, attestation, field, position, visible, view_name)
   	 	values (view_conf_id, attestation_id, view_conf_name, view_conf_position, view_conf_visible, v_name);
    else
    	update attestation_view t set t.view_name = v_name, t.state = 0 where t.attestation = attestation_id and t.field = view_conf_name;
   	end if;
    
    end loop;
  close cur_attest;
------END OF ENTITLEMENT_VIEW SECTION
  
  
  ------USER_VIEW SECTION
  v_name := 'User_View';
  
  open cur_attest for
  select att.id from attestation att where type=1 and state not in (5, 10); 
    loop
     fetch cur_attest into attestation_id;
     exit when cur_attest%NOTFOUND;
     
    view_conf_name := 'UE_DETAILS_REVIEW_PROCESS';
  	view_conf_visible := 0;  
    select count(1) into counter from attestation_view attview where attview.field = view_conf_name and attview.attestation = attestation_id;
    if ( counter = 0 or counter > 1) then
    	delete from attestation_view attview where attview.field = view_conf_name and attview.attestation = attestation_id;
    	select attestation_view_seq.nextval into view_conf_id from dual;
    	select ( max(t.position) + 1 ) into view_conf_position from attestation_view t where t.attestation = attestation_id and ( view_name is null or view_name <> 'Entitlement_View' );
    	if( view_conf_position is null ) then
    		view_conf_position := 1;
    	end if;
        insert into attestation_view (id, attestation, field, position, visible, view_name)
   	 	values (view_conf_id, attestation_id, view_conf_name, view_conf_position, view_conf_visible, v_name);
    else
    	update attestation_view t set t.view_name = v_name, t.state = 0 where t.attestation = attestation_id and t.field = view_conf_name;
   	end if;
   	end loop;
  close cur_attest;
   	
   	------ACCOUNT SECTION

   open cur_attest for
  select att.id from attestation att where type=4 and state not in (5, 10); 
    loop
     fetch cur_attest into attestation_id;
     exit when cur_attest%NOTFOUND;
     
    view_conf_name := 'UA_TABULAR_REVIEW_PROCESS';
  	view_conf_visible := 0;  
    select count(1) into counter from attestation_view attview where attview.field = view_conf_name and attview.attestation = attestation_id;
    if ( counter = 0 or counter > 1) then
    	delete from attestation_view attview where attview.field = view_conf_name and attview.attestation = attestation_id;
    	select attestation_view_seq.nextval into view_conf_id from dual;
    	select ( max(t.position) + 1 ) into view_conf_position from attestation_view t where t.attestation = attestation_id and ( view_name is null );
    	if( view_conf_position is null ) then
    		view_conf_position := 1;
    	end if;
        insert into attestation_view (id, attestation, field, position, visible, view_name)
   	 	values (view_conf_id, attestation_id, view_conf_name, view_conf_position, view_conf_visible, null);
    else
    	update attestation_view t set t.view_name = null, t.state = 0 where t.attestation = attestation_id and t.field = view_conf_name;
   	end if;
   
    
    end loop;
  close cur_attest;

end;
/
commit;
