set define off
declare
  im_id         numeric(16);
  im_name       varchar(256) := 'AGC';

  fc_id         numeric(16);
  fc_name       varchar(256) := 'system';
  
  fevt_id       numeric(16);
  fevt_name     varchar(256) := 'TARGET';
  
  f_id          numeric(16);
  f_name        varchar(256) := 'ACCOUNT_CREATE';

  f_lob         clob := 'package tCREATE_ACCOUNT3;
'||'
'||'import com.engiweb.logger.impl.Log4JImpl;
'||'import com.engiweb.profilemanager.backend.dao.db.SQLH
'||'import com.engiweb.pm.entity.BeanList;
'||'import com.engiweb.profilemanager.common.bean.AccountBean;
'||'import com.engiweb.profilemanager.common.bean.Block;
'||'import com.engiweb.profilemanager.common.bean.OrgUnitBean;
'||'import com.engiweb.profilemanager.common.bean.UserBean;
'||'import com.engiweb.profilemanager.common.bean.entitlement.EntitlementBean;
'||'import com.engiweb.profilemanager.common.bean.event.EntStateBean;
'||'import com.engiweb.profilemanager.common.bean.event.EventTargetBean;
'||'import com.engiweb.profilemanager.common.bean.rule.SyncStateBean;
'||'import com.engiweb.profilemanager.common.ruleengine.action.EntitlementAction;
'||'import com.engiweb.profilemanager.common.ruleengine.action.OrgUnitAction;
'||'import com.engiweb.profilemanager.common.ruleengine.action.UserAction;
'||'import com.engiweb.toolkit.common.DBMSException;
'||'import com.engiweb.profilemanager.common.bean.AccountAttrValueList
'||'import com.engiweb.profilemanager.common.interfaces.IAccountDirect
'||'import com.engiweb.toolkit.interfaces.JndiNames
'||'import com.engiweb.profilemanager.common.bean.targetattr.PwdManagementAttrValBean
'||'import common.direct.DirectFactory
'||'import com.engiweb.profilemanager.backend.business.direct.AccountDirect
'||'
'||'global com.engiweb.profilemanager.backend.dao.db.SQLH sql;
'||'global com.engiweb.logger.impl.Log4JImpl logger;
'||'
';
 
  fr_id         numeric(16);
  fr_name       varchar(256) := 'Create Account - userDn Matching Rule [V5.2.6]';
  fr_desc       varchar(512) := '[ V5.2.6 - 2019-10-28 ]'; 
  
  fr_lob        clob := 'rule "Create Account - userDn Matching Rule [V5.2.6]"
'||'when
'||'		event : EventTargetBean(  )
'||'		account : AccountBean(  )
'||'then
'||'
'||'  // [ V5.2.6 - 2019-10-28 ]
'||'
'||'  // Exit if account owner dn is null
'||'  if (event.getAttr8() == null) {
'||'    logger.info("Account owner DN is empty. Account is not created!");
'||'    return;
'||'  } else {
'||'    // Set owner DN to attr5
'||'    account.setAttr5(event.getAttr8());
'||'  }
'||'  
'||'  // If the account dn is set, then set it to the account.
'||'  if (event.getDn() != null) {
'||'    account.setDn(event.getDn());
'||'  }
'||'
'||'  // Exit if already matched by a customized rule
'||'  if (account.getPerson_id() != null) {
'||'    logger.info("Account already matched!");
'||'    return;
'||'  }
'||'
'||'  UserBean userFilter = new UserBean();
'||'  userFilter.setDn(event.getAttr8());
'||'
'||'  BeanList beanList = UserAction.find(sql, userFilter);
'||'  boolean found = !beanList.isEmpty();
'||'  if (found) {
'||'    logger.info("Account Matched by owner DN!");
'||'
'||'    userFilter = (UserBean) beanList.get(0);
'||'
'||'    account.setPerson_id(userFilter.getId());
'||'
'||'    if (account.getId() != null) {
'||'      // the account already exist but it is unmatched/orphan
'||'      AccountDirect aDirect = new AccountDirect();
'||'      aDirect.matchAccount(userFilter,account,true,sql);
'||'      logger.info("Account exist but it is unmatched/orphan");
'||'    } else {
'||'      UserAction.addAccount(sql, account);
'||'      logger.info("Account : " + account.getCode() + " created!");
'||'    }
'||'  }
'||'end
'||'
';

  counter       numeric(16);
begin
  select count(1) into counter from ideas_module t where lower ( t.code ) = lower ( im_name );
  if ( counter = 1 ) then
    select t.id into im_id from ideas_module t where lower ( t.code ) = lower ( im_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO IDEAS MODULE FOUND' );
  end if;

  select count(1) into counter from flow_context t where lower ( t.name ) = lower ( fc_name );
  if ( counter = 1 ) then
    select t.id into fc_id from flow_context t where lower ( t.name ) = lower ( fc_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW CONTEXT FOUND' );
  end if;

  select count(1) into counter from flow_event_type t
  where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  if ( counter = 1 ) then
    select t.id into fevt_id from flow_event_type t
    where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW EVENT TYPE FOUND' );
  end if;
  
  select count(1) into counter from flow t
  where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name ); 
  if ( counter = 1 ) then
    select t.id into f_id from flow t
    where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name );
	
	update flow set flow_lob = f_lob where id = f_id;
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW FOUND' );
  end if;

  select count(1) into counter from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );
  if ( counter = 0 ) then
    select flow_rule_seq.nextval into fr_id from dual;
    insert into flow_rule ( id, flow, name, description, rule_lob, ideas_module )
    values ( fr_id, f_id, fr_name, fr_desc, fr_lob, im_id );
  else
    select t.id into fr_id from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );

    update flow_rule set description = fr_desc where id = fr_id;

    update flow_rule set rule_lob = fr_lob where id = fr_id;
  end if;

end;
/
commit;
set define on
