set define off
declare
  im_id         numeric(16);
  im_name       varchar(256) := 'AGC';

  fc_id         numeric(16);
  fc_name       varchar(256) := 'system';
  
  fevt_id       numeric(16);
  fevt_name     varchar(256) := 'IN';
  
  f_id          numeric(16);
  f_name        varchar(256) := 'USER_ADD';

  f_lob         clob := 'package tADD_USER1;
'||'
'||'import com.engiweb.logger.impl.Log4JImpl;
'||'import com.engiweb.pm.entity.BeanList;
'||'import com.engiweb.profilemanager.backend.dao.db.SQLH;
'||'import com.engiweb.profilemanager.common.bean.AccountBean;
'||'import com.engiweb.profilemanager.common.bean.Block;
'||'import com.engiweb.profilemanager.common.enumerations.LockType;
'||'import com.engiweb.profilemanager.common.bean.entitlement.EntitlementBean;
'||'import com.engiweb.profilemanager.common.bean.ExternalInfo;
'||'import com.engiweb.profilemanager.common.bean.OrgUnitBean;
'||'import com.engiweb.profilemanager.common.bean.OrgUnitErcBean;
'||'import com.engiweb.profilemanager.common.bean.PwdCfgBean;
'||'import com.engiweb.profilemanager.common.bean.UserBean;
'||'import com.engiweb.profilemanager.common.bean.UserErcBean;
'||'import com.engiweb.profilemanager.common.bean.event.EventBean;
'||'import com.engiweb.profilemanager.common.bean.event.EventInBean;
'||'import com.engiweb.profilemanager.common.ruleengine.action.OrgUnitAction;
'||'import com.engiweb.profilemanager.common.ruleengine.action.UserAction;
'||'import com.engiweb.profilemanager.common.ruleengine.action.UtilAction;
'||'import com.engiweb.profilemanager.common.ruleengine.action.JobRoleAction;
'||'import com.engiweb.profilemanager.backend.business.direct.AccountDirect;
'||'import com.engiweb.toolkit.common.DBMSException;
'||'
'||'global com.engiweb.profilemanager.backend.dao.db.SQLH sql;
'||'global com.engiweb.logger.impl.Log4JImpl logger;
'||'
'||'
'||'
';
 
  fr_id         numeric(16);
  fr_name       varchar(256) := 'Assign Orphan Accounts Using User Dn';
  fr_desc       varchar(512) := '[ V1.1 - 2019-05-03 ]';
  
  fr_lob        clob := 'rule "Assign Orphan Accounts Using User Dn"
'||'when
'||'	event : EventInBean( )
'||'	userErcBean : UserErcBean( )
'||'	userBean : UserBean( )
'||'	extInfoBean : ExternalInfo( )
'||'	orgUnitBean : OrgUnitBean( )
'||'then
'||'// [ V1.1 - 2018-12-01 ]
'||'  String userDn = userBean.getDn();
'||'  if (userDn == null || userDn.length() == 0) {
'||'    logger.debug("User does not have DN set. Nothing to do.");
'||'    return;
'||'  }
'||'  AccountBean accountFilter = new AccountBean();
'||'  accountFilter.setAttr5(userDn);
'||'  AccountDirect accountDirect = new AccountDirect();
'||'  BeanList accountList = accountDirect.find(accountFilter, null, sql);
'||'  if (accountList == null || accountList.isEmpty()) {
'||'    logger.debug("No account found with owner dn:" + userDn);
'||'    return;
'||'  }
'||'  for (int i = 0; i < accountList.size(); i++) {
'||'    AccountBean acctBean = (AccountBean) accountList.get(i);
'||'    // if the account is orphan account, then assign the account.
'||'    if (acctBean.getPerson_id() == null) {
'||'      StringBuffer userAndAcctInfo = new StringBuffer("[firstName:").
'||'      append(userBean.getName()).append("][lastName:").
'||'      append(userBean.getSurname()).append("][accountUid:").
'||'      append(acctBean.getCode()).append("][accountConfigName:").
'||'      append(acctBean.getPwdcfg_name()).append("]");
'||'      try {
'||'        accountDirect.matchAccount(userBean, acctBean, true, sql);
'||'        logger.debug("The orphan account is assigned to the user using DN:" + userAndAcctInfo);
'||'      } catch (Exception e) {
'||'        logger.error("The account cannot be assigned to the user: " + userAndAcctInfo);
'||'      }
'||'    }
'||'  }
'||'end
'||'
';

  counter       numeric(16);
begin
  select count(1) into counter from ideas_module t where lower ( t.code ) = lower ( im_name );
  if ( counter = 1 ) then
    select t.id into im_id from ideas_module t where lower ( t.code ) = lower ( im_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO IDEAS MODULE FOUND' );
  end if;

  select count(1) into counter from flow_context t where lower ( t.name ) = lower ( fc_name );
  if ( counter = 1 ) then
    select t.id into fc_id from flow_context t where lower ( t.name ) = lower ( fc_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW CONTEXT FOUND' );
  end if;

  select count(1) into counter from flow_event_type t
  where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  if ( counter = 1 ) then
    select t.id into fevt_id from flow_event_type t
    where t.flow_context = fc_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fevt_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW EVENT TYPE FOUND' );
  end if;
  
  select count(1) into counter from flow t
  where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name ); 
  if ( counter = 1 ) then
    select t.id into f_id from flow t
    where t.ideas_module = im_id and t.flow_event_type = fevt_id and lower ( t.name ) = lower ( f_name );
	
	update flow set flow_lob = f_lob where id = f_id;
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO FLOW FOUND' );
  end if;

  select count(1) into counter from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );
  if ( counter = 0 ) then
    select flow_rule_seq.nextval into fr_id from dual;
    insert into flow_rule ( id, flow, name, description, rule_lob, ideas_module )
    values ( fr_id, f_id, fr_name, fr_desc, fr_lob, im_id );
  else
    select t.id into fr_id from flow_rule t where t.flow = f_id and t.ideas_module = im_id and lower ( t.name ) = lower ( fr_name );

    update flow_rule set description = fr_desc where id = fr_id;

    update flow_rule set rule_lob = fr_lob where id = fr_id;
  end if;

end;
/
commit;
set define on
