CREATE OR REPLACE TRIGGER TRG_PWDMANAGEMENT_BEFORE
  BEFORE INSERT OR UPDATE ON PWDMANAGEMENT
  FOR EACH ROW
declare
  cur_pwdcfg sys_refcursor;

  feedB      boolean;
  u_target   boolean;
  v_target   varchar(256);

  code_oper  varchar(128);
  oldpwd     varchar(128);
  newpwd     varchar(128);
  olduserid  varchar(128);
  newuserid  varchar(128);
  oldexpire  varchar(128);
  newexpire  varchar(128);
  oldchangelog  numeric(16);
  newchangelog  numeric(16);
  currentchangelog numeric(16);

  counter    numeric(16);
  disoper    numeric(16);

begin

  if ( updating and ( ( :old.CHALLENGE_COUNTER != :new.CHALLENGE_COUNTER )
       or ( :old.CHALLENGE_COUNTER is null and :new.CHALLENGE_COUNTER is not null )
       or ( :old.CHALLENGE_COUNTER is not null and :new.CHALLENGE_COUNTER is null ) ) ) then
    return;
  end if;

  if ( updating and ( ( :old.CHALLENGE_FAILED_ATTEMPT != :new.CHALLENGE_FAILED_ATTEMPT )
       or ( :old.CHALLENGE_FAILED_ATTEMPT is null and :new.CHALLENGE_FAILED_ATTEMPT is not null )
       or ( :old.CHALLENGE_FAILED_ATTEMPT is not null and :new.CHALLENGE_FAILED_ATTEMPT is null ) ) ) then
    return;
  end if;

  if ( updating and ( ( :old.CHALLENGE_TOKEN != :new.CHALLENGE_TOKEN )
       or ( :old.CHALLENGE_TOKEN is null and :new.CHALLENGE_TOKEN is not null )
       or ( :old.CHALLENGE_TOKEN is not null and :new.CHALLENGE_TOKEN is null ) ) ) then
    return;
  end if;

  if ( updating and ( ( :old.CHALLENGE_TOKEN_CREATION != :new.CHALLENGE_TOKEN_CREATION )
       or ( :old.CHALLENGE_TOKEN_CREATION is null and :new.CHALLENGE_TOKEN_CREATION is not null )
       or ( :old.CHALLENGE_TOKEN_CREATION is not null and :new.CHALLENGE_TOKEN_CREATION is null ) ) ) then
    return;
  end if;

  select count(1) into counter from tmp_codoperation;

  if ( counter = 0 ) then
    RAISE_APPLICATION_ERROR ( -20200, 'NO OPERATION CODE FOUND IN TMP_CODOPERATION TABLE');
  elsif ( counter = 1 ) then
    select code into code_oper from tmp_codoperation;
  elsif  ( counter > 1 ) then
    RAISE_APPLICATION_ERROR ( -20201, 'TOO MANY OPERATION CODE FOUND IN TMP_CODOPERATION TABLE');
  end if;

  if (code_oper is not null and INSTR(code_oper, 'ARM_', 1, 1) = 1) then
    feedB := true;
  else
    feedB := false;
  end if;
  
  if (code_oper is not null and INSTR(code_oper, 'MR_TARGET', 1, 1) = 1) then
    u_target := true;
  else
    u_target := false;
  end if;

  if (inserting) then
    -- attr1 contiene la password cifrata. Attr2 contiene il codice di blocco
    insert into eventpm
      (id, person, cod_operation, operation, pwdcfg, attr1, attr2, attr3, attr5, changelog)
    values
      (eventpm_seq.nextval,
       :new.person,
       code_oper,
       8,
       :new.pwdcfg,
       :new.code,
       :new.attr1,
       :new.attr2,
       :new.id,
       :new.changelog);
    
	-- if the account is disabled on create (block code on attr 2 is not equal to 000000)
    -- we must insert another event of disable user to account provisioning
    if (:new.attr2 is not null and :new.attr2 != '000000') THEN
    --account disabled event
    insert into eventpm
      (id, person, cod_operation, operation, pwdcfg, attr1, attr3, attr5)
    values
      (eventpm_seq.nextval,
       :new.person,
       code_oper,
       6,
       :new.pwdcfg,
       :new.code,
       :new.attr2,
       :new.id);
     end if;

    --2015-09-09 - Only in case of account with an expiration, put another entry in event_pm table
    if ( :new.expire is not null ) then
      insert into eventpm
        (id, person, cod_operation, operation, pwdcfg, attr1, attr2, attr5)
      values
        (eventpm_seq.nextval,
         :new.person,
         code_oper,
         10,
         :new.pwdcfg,
         :new.code,
         :new.expire,
         :new.id);
    end if;

    -- cancelliamo la password cifrata per connettore
    :new.attr1 := null;
    return;
  end if;

  if (updating) then
    oldpwd := :old.password;
    newpwd := :new.password;

    olduserid := :old.code;
    newuserid := :new.code;

    oldexpire := :old.expire;
    newexpire := :new.expire;
    
    oldchangelog := :old.changelog;
    newchangelog := :new.changelog;
    currentchangelog := null;
    
  end if;

  -- pwd
  if (oldpwd is null) then
    oldpwd := '_';
  end if;

  if (newpwd is null) then
    newpwd := '_';
  end if;

  --- userid
  if (olduserid is null) then
    olduserid := '_';
  end if;

  if (newuserid is null) then
    newuserid := '_';
  end if;
  
    --- changelog
  if (oldchangelog is null) then
    oldchangelog := 0;
  end if;

  if (newchangelog is null) then
    newchangelog := 0;
  end if;

  if (oldchangelog != newchangelog) then
     currentchangelog := newchangelog;
  end if;
  
  if (olduserid != newuserid or oldchangelog != newchangelog or u_target) then
    insert into eventpm
      (id, person, cod_operation, operation, pwdcfg, attr1, attr4, attr5, changelog)
    values
      (eventpm_seq.nextval,
       :new.person,
       code_oper,
       10,
       :new.pwdcfg,
       newuserid,
       olduserid,
       :new.id,
       currentchangelog);
  end if;

  if (oldpwd != newpwd or :new.attr1 is not null) then
    insert into eventpm
      (id, person, authorizations, cod_operation, operation, pwdcfg, attr1, attr2, attr5)
    values
      (eventpm_seq.nextval,
       :new.person,
       :new.id,
       code_oper,
       11,
       :new.pwdcfg,
       newuserid,
       :new.attr1,
       :new.id);

    -- propago su feedback solo in caso di cambio password da swim
    if (feedB) then

      open cur_pwdcfg for
        select distinct t.value
          from pwdcfg pwd, target t
         where pwd.id = :new.pwdcfg
           and pwd.id = t.pwdcfg
           and pwd.sync = 2;

      loop
        fetch cur_pwdcfg
          into v_target;
        exit when cur_pwdcfg%NOTFOUND;

        -- controllo del target
        if (v_target is not null) then
          insert into feedback
            (id, authorizations, application, cod_operation, operation)
          values
            (feedback_seq.nextval, :new.id, v_target, code_oper, 11);

        end if;
      end loop;

      close cur_pwdcfg;
    -- fine propagazione su feedback
    end if;
    -- cancelliamo la password cifrata per connettore
    :new.attr1 := null;
  end if;

  if (oldexpire != newexpire) then
    insert into eventpm
      (id, person, cod_operation, operation, pwdcfg, attr1, attr2, attr5, changelog)
    values
      (eventpm_seq.nextval,
       :new.person,
       code_oper,
       10,
       :new.pwdcfg,
       newuserid,
       newexpire,
       :new.id,
       currentchangelog);
  end if;

  if (:old.disabled <> :new.disabled) then
    disoper := 7;

    if (:new.disabled = 1) then
      disoper := 6;
    end if;

    --disabilita/abilita utente
    insert into eventpm
      (id, person, cod_operation, operation, pwdcfg, attr1, attr3, attr5)
    values
      (eventpm_seq.nextval,
       :new.person,
       code_oper,
       disoper,
       :new.pwdcfg,
       newuserid,
       :new.attr2,
       :new.id);

    -- 2016-03-07
    -- propago su feedback solo in caso il blocco/sblocco account provenga da swim
    if (feedB) then

      open cur_pwdcfg for
        select distinct t.value
          from pwdcfg pwd, target t
         where pwd.id = :new.pwdcfg
           and pwd.id = t.pwdcfg
           and pwd.sync = 2;

      loop
        fetch cur_pwdcfg
          into v_target;
        exit when cur_pwdcfg%NOTFOUND;

        -- controllo del target
        if (v_target is not null) then
          insert into feedback
            (id, authorizations, application, cod_operation, operation)
          values
            (feedback_seq.nextval, :new.id, v_target, code_oper, disoper);

        end if;
      end loop;

      close cur_pwdcfg;
    -- fine propagazione su feedback
    end if;
  end if;

end TRG_PWDMANAGEMENT_BEFORE;
/