CREATE OR REPLACE TRIGGER TRG_USER_ERC_TO_PM
  BEFORE INSERT OR UPDATE OR DELETE ON USER_ERC
  FOR EACH ROW
declare
  counter        	  numeric(16);
  cur_tmp             sys_refcursor;

  var_operation       event_in.operation%type;
  var_ext_table       event_in.ext_table%type;
  var_columns_changed event_in.ext_attr9%type;
  ou_oper             numeric(16);

  var_ou              user_erc.ou%type;
  var_action_type     user_erc.action_type%type;
  var_action_cause    user_erc.action_cause%type;
  var_source_type     user_erc.source_type%type;
  var_source_id	      user_erc.source_id%type;
  var_source_name     user_erc.source_name%type;
begin

  if (trim(upper(user)) = trim(upper('&IDEAS_SUPER_ADMIN_USER'))) then
    return;
  end if;

  -- Default mapping from USER_ERC to EVENT_IN
  --
  -- ext_table.ou ---> event_in.ext.attr2
  -- ext_table.action_type ---> event_in.ext.attr3
  -- ext_table.action_cause ---> event_in.ext.attr4
  -- var_columns_changed ---> event_in.ext.attr9

  -- var_columns_changed contains the columns changed name separated by ;
  -- columns monitored: PM_CODE;GIVEN_NAME;SURNAME;EMAIL;USER_TYPE;DISABLED;DELETED;ATTR1;ATTR2;ATTR3;ATTR4;ATTR5;

  -- ********************* insert ********************* --
  if (inserting) then
    var_operation := 1;
    if ( :new.schedule = 1 ) then
      var_operation := var_operation + 100;
    end if;

    var_ext_table    := :new.id;
    var_ou           := :new.ou;
    var_action_type  := :new.action_type;
    var_action_cause := :new.action_cause;
    var_source_type  := :new.source_type;
  	var_source_id	 := :new.source_id;
  	var_source_name  := :new.source_name;
    -- ********************* update ********************* --
  elsif (updating) then
    var_operation := 2;
    ou_oper := 12;
    if ( :new.schedule = 1 ) then
      var_operation := var_operation + 100;
      ou_oper       := ou_oper + 100;
    end if;

    var_ext_table    := :new.id;
    var_ou           := :new.ou;
    var_action_type  := :new.action_type;
    var_action_cause := :new.action_cause;
    var_source_type  := :new.source_type;
  	var_source_id	 := :new.source_id;
  	var_source_name  := :new.source_name;

    -- calculate var_columns_changed
    var_columns_changed := '';
    if ((:old.PM_CODE != :new.PM_CODE) or
       (:old.PM_CODE is null and :new.PM_CODE is not null) or
       (:old.PM_CODE is not null and :new.PM_CODE is null)
       ) then
      var_columns_changed := 'PM_CODE;';
    end if;
    if ((:old.GIVEN_NAME != :new.GIVEN_NAME) or
       (:old.GIVEN_NAME is null and :new.GIVEN_NAME is not null) or
       (:old.GIVEN_NAME is not null and :new.GIVEN_NAME is null)
       ) then
      var_columns_changed := var_columns_changed || 'GIVEN_NAME;';
    end if;
    if ((:old.SURNAME != :new.SURNAME) or
       (:old.SURNAME is null and :new.SURNAME is not null) or
       (:old.SURNAME is not null and :new.SURNAME is null)
       ) then
      var_columns_changed := var_columns_changed || 'SURNAME;';
    end if;
    if ((:old.EMAIL != :new.EMAIL) or
       (:old.EMAIL is null and :new.EMAIL is not null) or
       (:old.EMAIL is not null and :new.EMAIL is null)
       ) then
      var_columns_changed := var_columns_changed || 'EMAIL;';
    end if;
    if ((:old.USER_TYPE != :new.USER_TYPE) or
       (:old.USER_TYPE is null and :new.USER_TYPE is not null) or
       (:old.USER_TYPE is not null and :new.USER_TYPE is null)
       ) then
      var_columns_changed := var_columns_changed || 'USER_TYPE;';
    end if;
    if ((:old.DISABLED != :new.DISABLED) or
       (:old.DISABLED is null and :new.DISABLED is not null) or
       (:old.DISABLED is not null and :new.DISABLED is null)
       ) then
      var_columns_changed := var_columns_changed || 'DISABLED;';
    end if;
    if ((:old.DELETED != :new.DELETED) or
       (:old.DELETED is null and :new.DELETED is not null) or
       (:old.DELETED is not null and :new.DELETED is null)
       ) then
      var_columns_changed := var_columns_changed || 'DELETED;';
    end if;
    if ((:old.ATTR1 != :new.ATTR1) or
       (:old.ATTR1 is null and :new.ATTR1 is not null) or
       (:old.ATTR1 is not null and :new.ATTR1 is null)
       ) then
      var_columns_changed := var_columns_changed || 'ATTR1;';
    end if;
    if ((:old.ATTR2 != :new.ATTR2) or
       (:old.ATTR2 is null and :new.ATTR2 is not null) or
       (:old.ATTR2 is not null and :new.ATTR2 is null)
       ) then
      var_columns_changed := var_columns_changed || 'ATTR2;';
    end if;
    if ((:old.ATTR3 != :new.ATTR3) or
       (:old.ATTR3 is null and :new.ATTR3 is not null) or
       (:old.ATTR3 is not null and :new.ATTR3 is null)
       ) then
      var_columns_changed := var_columns_changed || 'ATTR3;';
    end if;
    if ((:old.ATTR4 != :new.ATTR4) or
       (:old.ATTR4 is null and :new.ATTR4 is not null) or
       (:old.ATTR4 is not null and :new.ATTR4 is null)
       ) then
      var_columns_changed := var_columns_changed || 'ATTR4;';
    end if;
    if ((:old.ATTR5 != :new.ATTR5) or
       (:old.ATTR5 is null and :new.ATTR5 is not null) or
       (:old.ATTR5 is not null and :new.ATTR5 is null)
       ) then
      var_columns_changed := var_columns_changed || 'ATTR5;';
    end if;

    -- Customizations ...
    --if ((:old.ATTR5 != :new.ATTR5) or
    --   (:old.ATTR5 is null and :new.ATTR5 is not null) or
    --   (:old.ATTR5 is not null and :new.ATTR5 is null)
    --   ) then
    --  var_columns_changed := var_columns_changed || 'ATTR5;';
    --end if;


    -- if OU changed generate a move user event before, operation=12
    if ( ( :old.ou is null and :new.ou is not null )
         or ( :old.ou is not null and :new.ou is null )
         or ( :old.ou != :new.ou ) ) then
      insert into event_in
        (id,
         ext_table,
         operation,
         state,
         date_process,
         last_mod_time,
         last_mod_user,
         ext_attr1,
         ext_attr2,
         ext_attr3,
         ext_attr4,
         erc,
         source_type,
     	 source_id,
     	 source_name)
      values
        (event_in_seq.nextval,
         var_ext_table,
         ou_oper,
         0,
         sysdate,
         sysdate,
         'trg_connector_user_to_pm',
         null,
         :new.ou,
         :new.action_type,
         :new.action_cause,
         'user_erc',
         var_source_type,
	     var_source_id,
    	 var_source_name);
    end if; --if ( :old.ou != :new.ou ) then

    -- ********************* delete ********************* --
  elsif (deleting) then
    var_operation := 3;
    if ( :old.schedule = 1 ) then
      var_operation := var_operation + 100;
    end if;

    var_ext_table    := :old.id;
    var_ou           := :old.ou;
    var_action_type  := :old.action_type;
    var_action_cause := :old.action_cause;
    
    select count(1) into counter from source_info si where si.entity = 1 and si.entity_id = :old.id;
    if ( counter = 1 ) then
    	open cur_tmp for
    		select si.source_type, si.source_id, si.source_name, si.action_type, si.action_cause
    		from source_info si
    		where si.entity = 1 and si.entity_id = :old.id;

       fetch cur_tmp into var_source_type, var_source_id, var_source_name, var_action_type, var_action_cause;
       close cur_tmp;
       
       delete from source_info si where si.entity = 1 and si.entity_id = :old.id;
    end if;

  end if; --if (inserting) then

  -- ********************* insert event ********************* --
  insert into event_in
    (id,
     ext_table,
     operation,
     state,
     date_process,
     last_mod_time,
     last_mod_user,
     ext_attr1,
     ext_attr2,
     ext_attr3,
     ext_attr4,
     ext_attr5,
     ext_attr6,
     ext_attr7,
     ext_attr8,
     ext_attr9,
     ext_attr10,
     erc,
     source_type,
     source_id,
     source_name)
  values
    (event_in_seq.nextval,
     var_ext_table,
     var_operation,
     0,
     sysdate,
     sysdate,
     'trg_connector_user_to_agc',
     null, -- customizable
     var_ou,
     var_action_type,
     var_action_cause,
     null, -- customizable
     null, -- customizable
     null, -- customizable
     null, -- customizable
     var_columns_changed,
     null,  -- used by the user_before rule = original cod_operation event discarded
     'user_erc',
     var_source_type,
     var_source_id,
     var_source_name);

  if (not deleting) then
    :new.action_type  := '0';
    :new.action_cause := '0';
  end if;

end TRG_USER_ERC_TO_PM;
/