CREATE OR REPLACE
FUNCTION rm_get_person ( profile_count IN NUMERIC(31) ) RETURN sys_refcursor IS
--Restituisce i PERSON che possiedono ALMENO i PROFILE presenti nella TMP_JOIN.
--
--Il numero dei PROFILE presenti nella TMP_JOIN Ã¨ passato dall'esterno
--poichÃ¨ esso viene restituito dalla procedura "init_entitlement" (che si deve
--usare obbligatoriamente prima di questa).
--
-- BREVE SPIEGAZIONE --
--
--Viene fatta una join tra i PROFILE contenuti nella TMP_JOIN, ENTITLEMENT_AUTH_PROFILE
--ed EMPLOYMENT. Vengono poi raggruppati i risultati per PERSON e scartati quelli
--che hanno un numero minore del numero di PROFILE passato.
--In questo modo si Ã¨ sicuri che tutti i PERSON risultanti dalla query possiedano
--ALMENO i PROFILE presenti nella TMP_JOIN.
--La join con la tabella JOB_UNIT Ã¨ necessaria solo per avere la ORGANIZATIONAL_UNIT
--in cui sono posizionati i PERSON.
cur_person sys_refcursor;

BEGIN
OPEN cur_person FOR SELECT
   a.person_id AS PERSON_ID,
   a.ou_id AS OU_ID
FROM    (
   SELECT
       /*+ ORDERED */
       DISTINCT e.person AS PERSON_ID,
       ju.organizational_unit AS OU_ID,
       efh.child AS PROFILE_ID
   FROM        tmp_join tj,
       entitlement_flat_hier efh,
       employment e,
       job_unit ju
   WHERE        tj.code = efh.child
       AND efh.child_int_type = 1
       --2015-07-03 - Aggiunta gestione degli external role fulfilled ma figli di altri external role fulfilled
       AND efh.ext_fulfillment_limit = 0
       AND efh.parent = e.entitlement
       AND e.job_unit = ju.id
       --2015-03-19 - Si escludono i ruoli in delega
       AND e.parent IS NULL
       --2015-04-22 - Si impone HIERARCHY=1
       AND e.hierarchy = 1
       AND e.hierarchy = ju.hierarchy
       --exclude from the consolidation employment not yest active
      AND (e.START_DATE IS NULL
       OR e.START_DATE<CURRENT_DATE)
       --2018-01-12 - si escludono employment legati ad account non di default
       AND NOT EXISTS (
           SELECT 1
       FROM            employment_pwdmanagement em,
           pwdmanagement pwdm
       WHERE            e.id = em.employment
           AND em.pwdmanagement = pwdm.id
           AND pwdm.is_default = 0) ) a
GROUP BY
   a.person_id,
   a.ou_id
HAVING
   COUNT(a.person_id) >= profile_count
ORDER BY
   a.ou_id ASC;


RETURN cur_person;

END rm_get_person;
/