CREATE OR REPLACE TRIGGER TRG_ADD_MODIFY_AUTHORIZATIONS
  AFTER INSERT OR UPDATE ON AUTHORIZATIONS
  FOR EACH ROW
declare
  to_feedback    boolean;
  old_deleted    boolean;
  new_deleted    boolean;

  code_oper      varchar(64);
  counter        numeric(16);
begin
  if ( upper( :new.cod_operation ) = upper ( 'IDEAS_AUTHORIZATIONS_ALIGNMENT' ) ) then
    return;
  end if;

  select count(1) into counter from tmp_codoperation;

  if ( counter = 0 ) then
    RAISE_APPLICATION_ERROR ( -20200, 'NO OPERATION CODE FOUND IN TMP_CODOPERATION TABLE');
  elsif ( counter = 1 ) then
    select code into code_oper from tmp_codoperation;
  elsif  ( counter > 1 ) then
    RAISE_APPLICATION_ERROR ( -20201, 'TOO MANY OPERATION CODE FOUND IN TMP_CODOPERATION TABLE');
  end if;

  if ( -- add permission operation, do not propagate on eventpm because without account (AlignEntitlementJob will update the fields later)
      inserting and :new.pwdmanagement is null and :new.account_code is null and
      :new.cod_operation = 'TRG_ADD_REMOVE_ENT_FLAT_HIER') then
    return;
  end if;

  to_feedback := :new.cod_operation is not null and INSTR(:new.cod_operation, 'ARM_', 1, 1) = 1;
  if ( updating or deleting ) then
    old_deleted := ( :old.entitlement is null or :old.entitlement_flat_hier is null or :old.employment is null );
  else
    old_deleted := false;
  end if;

  if ( inserting or updating ) then
    new_deleted := ( :new.entitlement is null or :new.entitlement_flat_hier is null or :new.employment is null );
  else
    new_deleted := false;
  end if;

  if ( inserting ) then
    insert into eventpm
      ( id, person, authorizations, cod_operation, operation )
    values
      ( eventpm_seq.nextval, :new.person, :new.id, code_oper, 1 );

    if ( to_feedback ) then
      insert into feedback
        ( id, authorizations, cod_operation, operation )
      values
        ( feedback_seq.nextval, :new.id, code_oper, 1 );
    end if;
  end if;

  if ( -- update of account fields on add permission operation, now propagate on eventpm (performed by AlignEntitlementJob)
      updating and :old.pwdmanagement is null and :new.pwdmanagement is not null and :old.account_code is null and
      :new.account_code is not null and :old.cod_operation = 'TRG_ADD_REMOVE_ENT_FLAT_HIER') then
    insert into eventpm
      (id, person, authorizations, cod_operation, operation)
    values
      (eventpm_seq.nextval, :new.person, :new.id, code_oper, 1);
    /* 
    if (to_feedback) then -- feedback disabled in the case of the previous condition
        insert into
         feedback( id, authorizations, cod_operation, operation )
         values( feedback_seq.nextval, :new.id, code_oper, 1 );
    end if; 
	*/
  end if;

  if ( updating and old_deleted = false and new_deleted = true ) then
    insert into eventpm
      ( id, person, authorizations, cod_operation, operation )
    values
      ( eventpm_seq.nextval, :old.person, :old.id, code_oper, 2 );

    if ( to_feedback ) then
      insert into feedback
        ( id, authorizations, cod_operation, operation )
      values
        ( feedback_seq.nextval, :old.id, code_oper, 2 );
    end if;
  end if;
end TRG_ADD_MODIFY_AUTHORIZATIONS;
/
