declare
  cur_realm         sys_refcursor;

  realm_id          numeric(16);

  scheduler_id      numeric(16);
  scheduler_name    varchar(256) := 'Singleton';

  class_id          numeric(16);
  class_name        varchar(256) := 'AuditDeltaCreationJob';
  class_value       varchar(256) := 'com.engiweb.profilemanager.job.AuditDeltaCreationJob';
  class_desc        varchar(512) := 'class name for audit delta creation';
  
  family_id         numeric(16);
  family_name       varchar(256) := 'Ideas';

  timer_id          numeric(16);
  timer_name        varchar(256) := 'AuditDeltaCreationTask';
  timer_desc        varchar(512) := 'Create audit old value and new value fields';
  timer_status      numeric(1)   := 0;
  timer_repetition  numeric(16)  := null;
  timer_cron        varchar(256) := '0 0 /1 * * ? *';
  timer_history     numeric(16)  := 0;

  work_id           numeric(16);
  work_name         varchar(256) := 'AuditDeltaCreation';
  work_desc         varchar(512) := 'Job to create audit new value and old value';
  
  timer_work_id     numeric(16);
  timer_work_ord    numeric(16);--no need to set

  counter           numeric(16);
begin
  select count(1) into counter from scheduler t where lower ( t.name ) = lower ( scheduler_name );
  if ( counter = 1) then
    select t.id into scheduler_id from scheduler t where lower ( t.name ) = lower ( scheduler_name );
  else
    RAISE_APPLICATION_ERROR ( -20200, 'NO SCHEDULER FOUND!');
  end if;

  open cur_realm for
    select t.id from realm t;
  loop
    fetch cur_realm into realm_id;
    exit when cur_realm%NOTFOUND;

    select count(1) into counter from class_name t where lower ( t.name ) = lower ( class_name ) and lower ( t.value ) = lower ( class_value ) and t.realm = realm_id;
    if ( counter = 1) then
      select t.id into class_id from class_name t where lower ( t.name ) = lower ( class_name ) and lower ( t.value ) = lower ( class_value ) and t.realm = realm_id;
    else
      select class_name_seq.nextval into class_id from dual;
      insert into class_name ( id, realm, name, value, description )
      values ( class_id, realm_id, class_name, class_value, class_desc );
    end if;

    select count(1) into counter from family t where lower ( t.name ) = lower ( family_name ) and t.realm = realm_id;
    if ( counter = 1) then
      select t.id into family_id from family t where lower ( t.name ) = lower ( family_name ) and t.realm = realm_id;
    else
      select family_seq.nextval into family_id from dual;
      insert into family ( id, realm, name )
      values ( family_id, realm_id, family_name );
    end if;

    select count(1) into counter from timer t where lower ( t.name ) = lower ( timer_name ) and t.realm = realm_id and t.scheduler = scheduler_id;
    if ( counter = 1) then
      select t.id into timer_id from timer t where lower ( t.name ) = lower ( timer_name ) and t.realm = realm_id and t.scheduler = scheduler_id;
    else
      select timer_seq.nextval into timer_id from dual;
      insert into timer ( id, realm, name, description, family, state, repetition, cron_string, scheduler, history )
      values ( timer_id, realm_id, timer_name, timer_desc, family_id, timer_status, timer_repetition, timer_cron, scheduler_id, timer_history );
    end if;

    select count(1) into counter from work t where lower ( t.name ) = lower ( work_name ) and t.realm = realm_id;
    if ( counter = 1) then
      select t.id into work_id from work t where lower ( t.name ) = lower ( work_name ) and t.realm = realm_id;
    else
      select work_seq.nextval into work_id from dual;
      insert into work ( id, realm, name, description, class_name )
      values ( work_id, realm_id, work_name, work_desc, class_id );
    end if;

    select count(1) into counter from timer_work t where t.timer = timer_id and t.work = work_id and t.realm = realm_id;
    if ( counter = 1) then
      select t.id into timer_work_id from timer_work t where t.timer = timer_id and t.work = work_id and t.realm = realm_id;
    else
      select timer_work_seq.nextval into timer_work_id from dual;

      select max ( t.seq_order ) into timer_work_ord from timer_work t where t.timer = timer_id and t.realm = realm_id;
      if ( timer_work_ord is null ) then
        timer_work_ord := 1;
      else
        timer_work_ord := timer_work_ord + 1;
      end if;
      
      insert into timer_work ( id, realm, timer, work, seq_order )
      values ( timer_work_id, realm_id, timer_id, work_id, timer_work_ord );
    end if;

  end loop;
  close cur_realm;

end;
/
commit;
