declare
  cur          sys_refcursor;

  tab_name     varchar2(128);
  pk_name      varchar2(128);
  seq_name     varchar2(128);

  max_pk       number(16);
  seq_pk       number(16);

  tab_counter  number(16);
  counter      number(16);

  ddl_query    varchar2(256);

  table_n1     varchar2(30) := 'DOMAIN';
  table_n2     varchar2(30) := 'RISK';
  table_n3     varchar2(30) := 'RISK_TYPE';
  table_n4     varchar2(30) := 'TASK';
  table_n5     varchar2(30) := 'TASK_PROPERTY';

  seq_name_fix varchar2(30) := 'TMP_SEQUENCE_GEN_SEQ';
begin
  select
    case when gt.tab_cnt > 0 then 0 else 1 end as tab_cnt into tab_counter
    --ut.tab_cnt - gt.tab_cnt as tab_diff
  from
  (
    select count(1) as tab_cnt, 'TABLE_COUNT' as tab from user_tables ut
  ) ut,
  (
    select nvl( count(1), 0 ) as tab_cnt, 'TABLE_COUNT' as tab from
    (
      select distinct t.owner, t.table_name from user_tab_privs t, user_synonyms tt
      where t.owner not in ( 'SYSTEM', 'SYS' ) and t.type = 'TABLE' and t.privilege = 'UPDATE'
      and t.owner = tt.table_owner and t.table_name = tt.table_name
    ) gt
  ) gt
  where ut.tab = gt.tab
  ;

  if ( tab_counter > 0 ) then
    open cur for
      select
        tc.table_name,
        ucc.column_name
      from
        user_tab_cols tc,
        user_constraints uc,
        user_cons_columns ucc
      where
        tc.table_name = uc.table_name
        and uc.constraint_name = ucc.constraint_name
        and ucc.column_name = tc.column_name
        and uc.constraint_type = 'P'
        and tc.data_type = 'NUMBER'
      order by tc.table_name;
  else
    open cur for
      select
        tc.table_name,
        ucc.column_name
      from
        (
          select distinct t.owner, t.table_name from user_tab_privs t, user_synonyms tt
          where t.owner not in ( 'SYSTEM', 'SYS' ) and t.type = 'TABLE' and t.privilege = 'UPDATE'
          and t.owner = tt.table_owner and t.table_name = tt.table_name
        ) gt,
        all_tab_cols tc,
        all_constraints uc,
        all_cons_columns ucc
      where
        gt.owner = tc.owner
        and uc.owner = ucc.owner
        and gt.table_name = tc.table_name
        and tc.table_name = uc.table_name
        and uc.constraint_name = ucc.constraint_name
        and ucc.column_name = tc.column_name
        and uc.constraint_type = 'P'
        and tc.data_type = 'NUMBER'
      order by tc.table_name;
  end if;

  loop
    fetch cur into tab_name, pk_name;
    exit when cur%notfound;

    max_pk   := null;
    seq_pk   := null;
    seq_name := tab_name||'_SEQ';

    if ( lower ( tab_name ) = lower ( table_n1 ) or lower ( tab_name ) = lower ( table_n2 )
         or lower ( tab_name ) = lower ( table_n3 ) or lower ( tab_name ) = lower ( table_n4 )
         or lower ( tab_name ) = lower ( table_n5 )
       ) then
      seq_name := seq_name_fix;
    end if;

    if ( tab_counter > 0 ) then
      select count(1) into counter from user_sequences us where us.sequence_name = seq_name;
    else
      select count(1) into counter from all_sequences us,
      (
        select distinct t.owner, t.table_name from user_tab_privs t left outer join user_synonyms tt
        on t.owner = tt.table_owner and t.table_name = tt.table_name
        where t.owner not in ( 'SYSTEM', 'SYS' ) and t.type = 'SEQUENCE' and t.privilege = 'SELECT'
      ) gt
       where us.sequence_owner = gt.owner and us.sequence_name = gt.table_name and us.sequence_name = seq_name;
    end if;

    --the sequence exists
    if ( counter = 1 ) then
      ddl_query := 'select max ( ' || pk_name || ' ) from ' || tab_name;
      execute immediate ( ddl_query ) into max_pk;

      if( max_pk is null ) then
        max_pk := 1;
      end if;

      if ( counter = 1 ) then
        ddl_query := 'select '||seq_name||'.nextval from dual';

        execute immediate ( ddl_query ) into seq_pk;
        dbms_output.put_line(tab_name|| ' - '||pk_name||': ' || max_pk || ' - SEQ: ' || seq_pk);

        --il valore della sequence e' minore del massimo della tabella
        if ( max_pk > seq_pk ) then
          loop
            --la clausola into  necessaria per far aggiornare veramente la sequence
            execute immediate ( ddl_query ) into seq_pk;

            exit when seq_pk > max_pk;
          end loop;
        end if;--if(seq_pk < max_pk)
      else
        dbms_output.put_line(tab_name||' - '|| max_pk || ' - not found');
      end if;--if( counter = 1 )
    end if;

  end loop;
  close cur;
end;
/
