CREATE OR REPLACE function rm_get_person
(
  profile_count in number
)
return sys_refcursor is
--Restituisce i PERSON che possiedono ALMENO i PROFILE presenti nella TMP_JOIN.
--
--Il numero dei PROFILE presenti nella TMP_JOIN Ã¨ passato dall'esterno
--poichÃ¨ esso viene restituito dalla procedura "init_entitlement" (che si deve
--usare obbligatoriamente prima di questa).
--
-- BREVE SPIEGAZIONE --
--
--Viene fatta una join tra i PROFILE contenuti nella TMP_JOIN, ENTITLEMENT_AUTH_PROFILE
--ed EMPLOYMENT. Vengono poi raggruppati i risultati per PERSON e scartati quelli
--che hanno un numero minore del numero di PROFILE passato.
--In questo modo si Ã¨ sicuri che tutti i PERSON risultanti dalla query possiedano
--ALMENO i PROFILE presenti nella TMP_JOIN.
--La join con la tabella JOB_UNIT Ã¨ necessaria solo per avere la ORGANIZATIONAL_UNIT
--in cui sono posizionati i PERSON.
  cur_person sys_refcursor;
begin
  open cur_person for
    select
      a.person_id AS PERSON_ID,
      a.ou_id as OU_ID
    from
    (
      select
        /*+ ORDERED */ distinct
        e.person as PERSON_ID,
        ju.organizational_unit as OU_ID,
        efh.child as PROFILE_ID
      from
        tmp_join tj,
        entitlement_flat_hier efh,
        employment e,
        job_unit ju
      where
        tj.code = efh.child
        and efh.child_int_type = 1
        --2015-07-03 - Aggiunta gestione degli external role fulfilled ma figli di altri external role fulfilled
        and efh.ext_fulfillment_limit = 0
        and efh.parent = e.entitlement
        and e.job_unit = ju.id
        --2015-03-19 - Si escludono i ruoli in delega
        and e.parent is null
        --2015-04-22 - Si impone HIERARCHY=1
        and e.hierarchy = 1
        and e.hierarchy = ju.hierarchy
		--exclude from the consolidation employment not yest active
      AND (e.START_DATE IS NULL
       OR e.START_DATE<CURRENT_DATE)
		--2018-01-12 - si escludono employment legati ad account non di default
		and not exists
         (select 1 from employment_pwdmanagement em, pwdmanagement pwdm
            where e.id = em.employment
            and em.pwdmanagement = pwdm.id
            and pwdm.is_default = 0)
    ) a
    group by a.person_id, a.ou_id
    having count(a.person_id) >= profile_count
    order by a.ou_id asc;

  return cur_person;
end rm_get_person;
/