create or replace procedure del_indx(index_name in varchar2) as
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-1418); -- index does not exist
begin
    execute immediate 'DROP INDEX ' || index_name;
exception
    when others then null;
end del_indx;
/

create or replace procedure create_indx(stat in varchar2) as
  exception1  EXCEPTION;
  PRAGMA EXCEPTION_INIT(exception1,-00955); -- name is already used by an existing object
begin
    execute immediate (stat);
exception
    when exception1 then null;
end create_indx;
/

CALL del_indx('APP_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX APP_LNAME_IDX ON APPLICATION
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('ENTITLEMENT_FULL_UNIQUE_INDX');

CALL create_indx('
CREATE UNIQUE INDEX ENTITLEMENT_FULL_UNIQUE_INDX ON ENTITLEMENT
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), INT_TYPE, EXT_TYPE, APPLICATION, PROFILE_TYPE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  

CALL del_indx('ENTITLEMENT_LCODE_IDX');

CALL create_indx('
CREATE UNIQUE INDEX ENTITLEMENT_LCODE_IDX ON ENTITLEMENT
(NLS_LOWER(CODE,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('ENTITLEMENT_FAMILY_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX ENTITLEMENT_FAMILY_LNAME_IDX ON ENTITLEMENT_FAMILY
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('ENT_OBJ_EXT_ENT_TYPE_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX ENT_OBJ_EXT_ENT_TYPE_LNAME_IDX ON ENTITLEMENT_OBJ_EXT
(ENTITLEMENT, INT_TYPE, NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('HIERARCHY_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX HIERARCHY_LNAME_IDX ON HIERARCHY
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('OU_HIERARCHY_LCODE_IDX');

CALL create_indx('
CREATE UNIQUE INDEX OU_HIERARCHY_LCODE_IDX ON ORGANIZATIONAL_UNIT
(HIERARCHY, NLS_LOWER(CODE,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('OUTYPE_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX OUTYPE_LNAME_IDX ON ORGANIZATIONAL_UNIT_TYPE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('PERSON_LCODE_ID_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PERSON_LCODE_ID_IDX ON PERSON
(NLS_LOWER(CODE,''NLS_SORT = XTurkish''), ID)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('PERSON_LCODE_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PERSON_LCODE_IDX ON PERSON
(NLS_LOWER(CODE,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');

  
CALL del_indx('PERSONTYPE_LNAME_ID_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PERSONTYPE_LNAME_ID_IDX ON PERSON_TYPE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), ID)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');

  
CALL del_indx('PERSONTYPE_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PERSONTYPE_LNAME_IDX ON PERSON_TYPE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');

  
CALL del_indx('PG_ROOT_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PG_ROOT_LNAME_IDX ON PROFILE_GROUP
(ROOT, NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');

  
CALL del_indx('PROFILE_GROUP_TYPE_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PROFILE_GROUP_TYPE_LNAME_IDX ON PROFILE_GROUP_TYPE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');

  
CALL del_indx('PROFILE_TYPE_LNAME_APP_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PROFILE_TYPE_LNAME_APP_IDX ON PROFILE_TYPE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), APPLICATION)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
 
  
CALL del_indx('PROPERTY_KEY_LNAME_ENTITY_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PROPERTY_KEY_LNAME_ENTITY_IDX ON PROPERTY_KEY
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), ENTITY)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('PWDCFG_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PWDCFG_LNAME_IDX ON PWDCFG
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('PWDCFG_AK_PWDCFG_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PWDCFG_AK_PWDCFG_LNAME_IDX ON PWDCFG_ATTR_KEY
(PWDCFG, NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('PWDCFGCNT_LNAME_CFG_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PWDCFGCNT_LNAME_CFG_IDX ON PWDCFGCNT
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), PWDCFG)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('PWDDICT_LNAME_PWDCFG_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PWDDICT_LNAME_PWDCFG_IDX ON PWDDICTIONARY
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), PWDCFG)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('PWDMAN_LCODE_PWDCFG_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PWDMAN_LCODE_PWDCFG_IDX ON PWDMANAGEMENT
(NLS_LOWER(CODE,''NLS_SORT = XTurkish''), PWDCFG)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('PWDMANTYPE_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PWDMANTYPE_LNAME_IDX ON PWDMANAGEMENT_TYPE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('PWDMANTYPE_LNAME_ID_IDX');

CALL create_indx('
CREATE UNIQUE INDEX PWDMANTYPE_LNAME_ID_IDX ON PWDMANAGEMENT_TYPE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), ID)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('RESOURC_RTNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX RESOURC_RTNAME_IDX ON RESOURC
(RESOURCE_TYPE, NLS_UPPER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('RF_NAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX RF_NAME_IDX ON RESOURCE_FAMILY
(NLS_UPPER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('RESTYPE_RESFAM_NAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX RESTYPE_RESFAM_NAME_IDX ON RESOURCE_TYPE
(RESOURCE_FAMILY, NLS_UPPER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('SERVICEATTR_LNAME_PROFILE_IDX');

CALL create_indx('
CREATE UNIQUE INDEX SERVICEATTR_LNAME_PROFILE_IDX ON SERVICE_ATTRIBUTE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), PROFILE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('SERVATTRLOOKUP_LNAME_VALUE_IDX');

CALL create_indx('
CREATE UNIQUE INDEX SERVATTRLOOKUP_LNAME_VALUE_IDX ON SERVICE_ATTRIBUTE_LOOKUP
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), VALUE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 
 
  
CALL del_indx('TARGET_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX TARGET_LNAME_IDX ON TARGET
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  '); 

--ARC
  
CALL del_indx('ENVIRONMENT_LNAME_ID_IDX');

CALL create_indx('
CREATE UNIQUE INDEX ENVIRONMENT_LNAME_ID_IDX ON ENVIRONMENT
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), ID)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('RISK_NAME_ENV_IDX');

CALL create_indx('
CREATE UNIQUE INDEX RISK_NAME_ENV_IDX ON RISK
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), ENVIRONMENT)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
    
  
CALL del_indx('TASK_ENV_LCODE_UDX');

CALL create_indx('
CREATE UNIQUE INDEX TASK_ENV_LCODE_UDX ON TASK
(ENVIRONMENT, NLS_LOWER(CODE,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('ATT_LNAME_TYPE_INDX');

CALL create_indx('
CREATE UNIQUE INDEX ATT_LNAME_TYPE_INDX ON ATTESTATION
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), TYPE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
      
--AP

CALL del_indx('APPROVER_TYPE_UK');

CALL create_indx('
CREATE UNIQUE INDEX APPROVER_TYPE_UK ON APPROVER_TYPES
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('CFG_ACTIVITY_LACTVITY_NAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX CFG_ACTIVITY_LACTVITY_NAME_IDX ON CFG_ACTIVITY
(NLS_LOWER(ACTIVITY_NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('CFG_DISPLAY_ENTITY_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX CFG_DISPLAY_ENTITY_LNAME_IDX ON CFG_DISPLAY_ENTITY
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('CFG_DISP_EFIELD_NAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX CFG_DISP_EFIELD_NAME_IDX ON CFG_DISPLAY_ENTITY_FIELD
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), CFG_DISPLAY_ENTITY)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('MN_R_M_UNIQUE_IDX');

CALL create_indx('
CREATE UNIQUE INDEX MN_R_M_UNIQUE_IDX ON MN_ROLE_MAPPING
(NLS_LOWER(ROLENAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
--EMS
CALL del_indx('EMS_CONFIGURATION_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX EMS_CONFIGURATION_LNAME_IDX ON EMS_CONFIGURATION
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('EMS_LANGUAGE_LNAME_LCOU_IDX');

CALL create_indx('
CREATE UNIQUE INDEX EMS_LANGUAGE_LNAME_LCOU_IDX ON EMS_LANGUAGE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), NLS_LOWER(COUNTRY,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('EMS_LOCALIZATION_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX EMS_LOCALIZATION_LNAME_IDX ON EMS_LOCALIZATION
(NLS_LOWER(CODE,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
CALL del_indx('EMS_TEMPLATE_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX EMS_TEMPLATE_LNAME_IDX ON EMS_TEMPLATE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
--CONNECTOR


CALL del_indx('CLASS_NAME_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX CLASS_NAME_LNAME_IDX ON CLASS_NAME
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('CONNECTOR_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX CONNECTOR_LNAME_IDX ON CONNECTOR
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('CONN_PROP_LNAME_CONNECTOR_IDX');

CALL create_indx('
CREATE UNIQUE INDEX CONN_PROP_LNAME_CONNECTOR_IDX ON CONNECTOR_PROPERTY
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), CONNECTOR)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('DRIVER_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX DRIVER_LNAME_IDX ON DRIVER
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('DRIVER_PROP_LNAME_DRIVER_IDX');

CALL create_indx('
CREATE UNIQUE INDEX DRIVER_PROP_LNAME_DRIVER_IDX ON DRIVER_PROPERTY
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), DRIVER)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('DRIVER_TYPE_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX DRIVER_TYPE_LNAME_IDX ON DRIVER_TYPE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('FUNCTION_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX FUNCTION_LNAME_IDX ON FUNCTION
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');

  
--RULE ENGINE

CALL del_indx('FLOW_LNAME_FLOW_EV_TYPE_IDX');

CALL create_indx('
CREATE UNIQUE INDEX FLOW_LNAME_FLOW_EV_TYPE_IDX ON FLOW
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), FLOW_EVENT_TYPE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('FLOW_EV_T_LNAME_FLOW_CONT_IDX');

CALL create_indx('
CREATE UNIQUE INDEX FLOW_EV_T_LNAME_FLOW_CONT_IDX ON FLOW_EVENT_TYPE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), FLOW_CONTEXT, IDEAS_MODULE)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('FLOW_RULE_LNAME_FLOW_IDX');

CALL create_indx('
CREATE UNIQUE INDEX FLOW_RULE_LNAME_FLOW_IDX ON FLOW_RULE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), FLOW)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('FLOW_STD_CONF_LNA_FLOW_DG_IDX');

CALL create_indx('
CREATE UNIQUE INDEX FLOW_STD_CONF_LNA_FLOW_DG_IDX ON FLOW_STD_CONF
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''), FLOW, DATA_GROUP)
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');

  
--LOCALIZATION

CALL del_indx('LANGUAGE_LCODE_COUNTRY_IDX');

CALL create_indx('
CREATE UNIQUE INDEX LANGUAGE_LCODE_COUNTRY_IDX ON LANGUAGE
(NLS_LOWER(CODE,''NLS_SORT = XTurkish''), NLS_LOWER(COUNTRY,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('LANGUAGE_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX LANGUAGE_LNAME_IDX ON LANGUAGE
(NLS_LOWER(NAME,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');


CALL del_indx('LOCALIZATION_LNAME_IDX');

CALL create_indx('
CREATE UNIQUE INDEX LOCALIZATION_LNAME_IDX ON LOCALIZATION
(NLS_LOWER(CODE,''NLS_SORT = XTurkish''))
NOLOGGING
NOPARALLEL
TABLESPACE &INDEX_TABLESPACE COMPUTE STATISTICS
  ');
  
  
drop procedure del_indx;

drop procedure create_indx;

